@@ -13,6 +13,7 @@ from jinja2 import Environment, FileSystemLoader
 
 DEFAULT_VERBOSE = True
 
+MAX_UNIQUE_VALUES_FOR_EXAMPLES = 4
 
 class Manager:
     """Class for managing the creation of the validation modules."""
@@ -71,7 +72,7 @@ class Manager:
 
         if extension == ".csv":
             self._generate_validation_modules_for_tsv_file(infile, is_tsv=False)
-        elif extension == ".tsv":
+        elif extension == ".tsv" or extension == ".txt":
             self._generate_validation_modules_for_tsv_file(infile, is_tsv=True)
         else:
             logging.error(
@@ -212,6 +213,7 @@ class Manager:
                     "column_name": column_name,
                     "column_position": column_position + 1,
                     "class_name": class_name,
+                    "examples": []
                 }
 
             uniq_val_lookup = {}
@@ -235,12 +237,22 @@ class Manager:
                             continue
                         # print(f"{row=}")
                         val = row[column_position]
+                        if val is None or val == "":
+                            # Skip empty values
+                            continue
                         if val not in uniq_val_lookup:
                             uniq_val_lookup[val] = 0
                             uniq_val_list.append(val)
+                            if (len(lookup[attribute_name]["examples"]) < MAX_UNIQUE_VALUES_FOR_EXAMPLES):
+                                lookup[attribute_name]["examples"].append(val)
                             uniq_val_ctr += 1
                         uniq_val_lookup[val] += 1
 
+            if uniq_val_ctr == 0:
+                lookup[attribute_name]["required"] = False
+            else:
+                lookup[attribute_name]["required"] = True
+
             datatype = self._determine_datatype(uniq_val_list)
 
             if datatype == "different":
@@ -248,6 +260,10 @@ class Manager:
             else:
                 lookup[attribute_name]["datatype"] = datatype
 
+
+            str_len_min = 0
+            str_len_max = 0
+
             if uniq_val_ctr <= self.max_equality_values:
                 logging.info(
                     f"Will generate enum class for attribute '{attribute_name}' for column '{column_name}' because the max unique values is '{uniq_val_ctr}'"
@@ -257,6 +273,28 @@ class Manager:
                 lookup[attribute_name]["uniq_values"] = []
                 for uniq_val in uniq_val_lookup:
                     lookup[attribute_name]["uniq_values"].append(uniq_val)
+                    if datatype == "str":
+                        str_len = len(uniq_val)
+                        if str_len_min == 0 or str_len < str_len_min:
+                            str_len_min = str_len
+                        if str_len > str_len_max:
+                            str_len_max = str_len
+                    elif datatype == "int" or datatype == "float":
+                        if datatype == "int":
+                            uniq_val = int(uniq_val)
+                        elif datatype == "float":
+                            uniq_val = float(uniq_val)
+                        if "min" not in lookup[attribute_name]:
+                            lookup[attribute_name]["min"] = uniq_val
+                        elif uniq_val < lookup[attribute_name]["min"]:
+                            lookup[attribute_name]["min"] = uniq_val
+                        if "max" not in lookup[attribute_name]:
+                            lookup[attribute_name]["max"] = uniq_val
+                        elif uniq_val > lookup[attribute_name]["max"]:
+                            lookup[attribute_name]["max"] = uniq_val
+                if datatype == "str":
+                    lookup[attribute_name]["min"] = str_len_min
+                    lookup[attribute_name]["max"] = str_len_max
 
             self._write_column_report_file(
                 column_name,
@@ -448,6 +486,12 @@ class Manager:
         # Specify the name of the template file
         template_name = "record.py"
 
+        if "validation_functions" in self.config:
+            lookup["validation_functions"] = self.config["validation_functions"]
+            logging.info(f"Added the validation functions to the lookup dictionary from the configuration file '{self.config_file}'")
+        else:
+            logging.warning(f"Did not find any validation functions in the configuration file '{self.config_file}'")
+
         # Create a dictionary with data to be passed to the template
         data = {
             "lookup": lookup,
@@ -499,8 +543,8 @@ class Manager:
     def _determine_datatype(self, values: List[Any]) -> str:
         # Check if the array is not empty
         if not values:
-            logging.error("values array is empty")
-            sys.exit(1)
+            logging.warning("The values array is empty so returning 'str' as the datatype.")
+            return "str"
 
         first_value = values[0]
         first_datatype = None
