@@ -6,7 +6,7 @@ from enum import Enum
 from typing import Union
 
 
-import pydantic
+from pydantic import BaseModel, constr, confloat, conint, Field
 
 
 {% for attribute_name in lookup %}
@@ -35,11 +35,27 @@ class Invalid{{ lookup[attribute_name].class_name }}Error(Exception):
 
 {% endfor %}
 
-class Record(pydantic.BaseModel):
+class Record(BaseModel):
     """Class for encapsulating the rows in {{ file_type }} files."""
-    {%- for attribute_name in lookup %}
-    {{ attribute_name }}: {{ lookup[attribute_name].datatype }}
-    {%- endfor %}
+    {% for attribute_name in lookup -%}
+    {{ attribute_name }}: {{ lookup[attribute_name].datatype }} = Field(
+        {% if lookup[attribute_name].required -%}
+        ...,  # Indicates this is a required field
+        {% endif %}
+        {% if lookup[attribute_name].examples -%}
+        example={{ lookup[attribute_name].examples -}},
+        {% endif %}
+        description="TBD",
+        frozen=True,
+        {% if lookup[attribute_name].datatype == "str" -%}
+        min_length={{ lookup[attribute_name].min }},
+        max_length={{ lookup[attribute_name].max }},
+        {% elif lookup[attribute_name].datatype == "float" or lookup[attribute_name].datatype == "int" -%}
+        ge={{ lookup[attribute_name].min }},
+        le={{ lookup[attribute_name].max }},
+        {% endif %}
+    )
+    {% endfor %}
 
 
     @pydantic.root_validator(pre=True)
@@ -47,10 +63,25 @@ class Record(pydantic.BaseModel):
     def is_record_valid(cls, values) -> None:
         # TODO: need to implement the root validator
         # raise InvalidRecordError(message="")
+
+        {% for func in lookup.validation_functions -%}
+        cls.{{ func.name }}(values)
+        {% endfor %}
         return values
 
-    {% for attribute_name in lookup %}
+    {% for func in lookup.validation_functions -%}
+    @classmethod
+    def {{ func.name }}(cls, values):
+        """{{ func.description }}
+        Args:
+            values (Dict[str, Any]): The dictionary containing each of the attributes and their corresponding value.
+        Raises:
+            ValueError
+        """
+        {{ func.definition }}
+    {% endfor %}
 
+    {% for attribute_name in lookup %}
     @pydantic.validator("{{ attribute_name }}")
     @classmethod
     def is_{{ attribute_name }}_valid(cls, value):
